import request from '@/utils/request'

// 新增金刚区
export function quickLinkAdd (data) {
  return request({
    url: '/info/quick/link/add',
    method: 'post',
    data
  })
}
// 修改金刚区
export function quickLinkEdit (data) {
  return request({
    url: '/info/quick/link/edit',
    method: 'post',
    data
  })
}
// 查询广告列表
export function quickLinkPage (query) {
  return request({
    url: '/info/quick/link/page',
    method: 'get',
    params: query
  })
}
// 获取广告详细信息
export function quickLinkInfo (id) {
  return request({
    url: `/info/quick/link/info/${id}`,
    method: 'get',
  })
}
// 修改广告状态
export function quickLinkSetStatus (id) {
  return request({
    url: `/info/quick/link/updateStatus/${id}`,
    method: 'post',
  })
}
// 删除广告
export function quickLinkDelSingle (ids) {
  return request({
    url: `/info/quick/link/del/${ids}`,
    method: 'post',
  })
}
// 通过协议code获取协议详细信息
export function protocolInfo (code) {
  return request({
    url: `/admin/protocol/info/${code}`,
    method: 'get',
  })
}
// 保存协议管理
export function protocolSave (data) {
  return request({
    url: `/admin/protocol/save`,
    method: 'post',
    data
  })
}
// 新增常见问题
export function problemAdd (data) {
  return request({
    url: `/admin/common/problem/add`,
    method: 'post',
    data
  })
}
// 修改常见问题
export function problemEdit (data) {
  return request({
    url: `/admin/common/problem/edit`,
    method: 'post',
    data
  })
}
// 获取常见问题详细信息
export function problemInfo (id) {
  return request({
    url: `/admin/common/problem/info/${id}`,
    method: 'get',
  })
}
// 查询常见问题列表
export function problemPage (query) {
  return request({
    url: '/admin/common/problem/page',
    method: 'get',
    params: query
  })
}
// 删除常见问题(单个删除)
export function problemDel (id) {
  return request({
    url: `/admin/common/problem/del/single/${id}`,
    method: 'post',
  })
}
// 新增热门城市
export function hotCityAdd (data) {
  return request({
    url: `/hotcity/hotCity/add`,
    method: 'post',
    data
  })
}
// 修改热门城市
export function hotCityEdit (data) {
  return request({
    url: `/hotcity/hotCity/edit`,
    method: 'post',
    data
  })
}
// 删除热门城市
export function hotCityDel (ids) {
  return request({
    url: `/hotcity/hotCity/del/${ids}`,
    method: 'post',
  })
}
// 获取热门城市详细信息
export function hotCityInfo (id) {
  return request({
    url: `/hotcity/hotCity/info/${id}`,
    method: 'get'
  })
}
// 分页查询热门城市列表
export function hotCityPage (query) {
  return request({
    url: '/hotcity/hotCity/page',
    method: 'get',
    params: query
  })
}
// 设置上架状态
export function hotCitySetStatus (id) {
  return request({
    url: `/hotcity/hotCity/setStatus/${id}`,
    method: 'post',
  })
}
// 新增快递公司，用于存储快递公司的基本信息
export function expressCompanyAdd (data) {
  return request({
    url: `/base/expressCompany/add`,
    method: 'post',
    data
  })
}
// 修改快递公司，用于存储快递公司的基本信息
export function expressCompanyEdit (data) {
  return request({
    url: `/base/expressCompany/edit`,
    method: 'post',
    data
  })
}
// 删除快递公司，用于存储快递公司的基本信息
export function expressCompanyDel (ids) {
  return request({
    url: `/base/expressCompany/del/${ids}`,
    method: 'post',
  })
}
// 获取快递公司，用于存储快递公司的基本信息详细信息
export function expressCompanyInfo (id) {
  return request({
    url: `/base/expressCompany/info/${id}`,
    method: 'get'
  })
}
// 查询快递公司，用于存储快递公司的基本信息列表

export function expressCompanyPage (query) {
  return request({
    url: `/base/expressCompany/page`,
    method: 'get',
    params: query
  })
}
// 查询快递公司，用于存储快递公司的基本信息列表
export function expressCompanyList () {
  return request({
    url: `/base/expressCompany/list`,
    method: 'get',
  })
}
// 设置积分商城销售配置
export function shopSaleConfigSet (data) {
  return request({
    url: `/shop/shopSaleConfig/set`,
    method: 'post',
    data
  })
}
// 获取积分商城销售配置详细信息
export function shopSaleConfigDefault () {
  return request({
    url: `/shop/shopSaleConfig/default`,
    method: 'get',
  })
}
// 常见问题上下架
export function problemStatus (id) {
  return request({
    url: `/admin/common/problem/status/${id}`,
    method: 'post',
  })
}
// 查询服务电话列表
export function operatingPhoneList () {
  return request({
    url: `/info/operatingPhone/list`,
    method: 'get',
  })
}
// 服务电话列表批量编辑
export function operatingPhoneBatchEdit (data) {
  return request({
    url: `/info/operatingPhone/batchEdit`,
    method: 'put',
    data
  })
}